"mvmeta".
"qtest"(object, ...)
"print"(x, digits=3, ...)"mvmeta" and "qtest.mvmeta", respectively."qtest.mvmeta" with the following components:df.print method function for class "qtest.mvmeta" does not return any value.
S of mvmeta objects. This is equal to test the hypothesis that the between-study (co)variance matrix is a zero matrix, and there is no random deviation in study-specific estimates. Tests for single outcome parameters, comparable to estimates from multiple univariate meta-analysis, are also reported. This test reduces to the standard Q test in univariate models. The function compute the statistics by actually fitting the related fixed-effects model, re-evaluating the call of the model with method changed to "fixed".
Berkey, CS, Hoaglin DC, et al. (1998). Meta-analysis of multiple outcomes by regression with random effects. Statistics in Medicine. 17(22):2537--2550.
Ritz J, Demidenkob E, Spiegelman G (2008). Multivariate meta-analysis for data consortia, individual patient meta-analysis, and pooling projects. Journal of Statistical Planning and Inference. 139(7):1919--1933.
qtest for the generic method function. See mvmeta-package for an overview of the package and modelling framework.
# RUN THE MODEL
model <- mvmeta(cbind(PD,AL)~1,S=berkey98[5:7],data=berkey98)
# MULTIVARIATE COCHRAN Q TEST FOR HETEROGENEITY
test <- qtest(model)
print(test,digits=2)
unclass(test)
Run the code above in your browser using DataLab