"mvmeta".
"summary"(object, ci.level=0.95, ...)
"print"(x, digits=4, ...)
"print"(x, digits=4, ...)"mvmeta" produced by a call to mvmeta."mvmeta" or "summary.mvmeta", produced by calls to mvmeta or summary.mvmeta, respectively.summary method function for mvmeta objects produces a list of class "summary.mvmeta". The components of the lists are some of those stored in the related mvmeta object, plus the following:mvmeta objects, simply reporting the point estimates (see mvmetaObject).mvmeta model, obtained through a call to AIC.mvmeta model, obtained through a call to BIC.vcov (see mvmetaObject and vcov).Psi (see see mvmetaObject).qtest.mvmeta object without its class, obtained through qtest.print method functions for classes "mvmeta" and "summary.mvmeta" do not return any value.
print method function for class "mvmeta" only returns basic information on the fitted model, namely the call, estimated fixed-effects coefficients, dimensions and fit statistics (log-likelihood, AIC, BIC).The summary method function computes additional statistics and tests, and produces a list object of class "summary.mvmeta". The print method function for this class shows additional information, such as tables reporting the estimates for the fixed and random-effects parts of the model, Cochran Q test for heterogeneity and $I^2$.
mvmeta and mvmetaObject.
# RUN THE MODEL
model <- mvmeta(cbind(PD,AL)~pubyear,S=berkey98[5:7],data=berkey98)
# SIMPLE PRINT
model
# DEFINE DIGITS
print(model,digit=2)
# SUMMARY WITH 80TH CONFIDENCE INTERVALS
summary(model,ci.level=0.80)
Run the code above in your browser using DataLab